UnwindSafe

Trait UnwindSafe 

1.9.0 · Source
pub auto trait UnwindSafe { }
A marker trait which represents “panic safe” types in Rust.

This trait is implemented by default for many types and behaves similarly in terms of inference of implementation to the Send and Sync traits. The purpose of this trait is to encode what types are safe to cross a catch_unwind boundary with no fear of unwind safety.

What is unwind safety?

In Rust a function can “return” early if it either panics or calls a function which transitively panics. This sort of control flow is not always anticipated, and has the possibility of causing subtle bugs through a combination of two critical components:

  1. A data structure is in a temporarily invalid state when the thread panics.
  2. This broken invariant is then later observed.

Typically in Rust, it is difficult to perform step (2) because catching a panic involves either spawning a thread (which in turn makes it difficult to later witness broken invariants) or using the catch_unwind function in this module. Additionally, even if an invariant is witnessed, it typically isn’t a problem in Rust because there are no uninitialized values (like in C or C++).

It is possible, however, for logical invariants to be broken in Rust, which can end up causing behavioral bugs. Another key aspect of unwind safety in Rust is that, in the absence of unsafe code, a panic cannot lead to memory unsafety.

That was a bit of a whirlwind tour of unwind safety, but for more information about unwind safety and how it applies to Rust, see an associated RFC.

What is UnwindSafe?

Now that we’ve got an idea of what unwind safety is in Rust, it’s also important to understand what this trait represents. As mentioned above, one way to witness broken invariants is through the catch_unwind function in this module as it allows catching a panic and then re-using the environment of the closure.

Simply put, a type T implements UnwindSafe if it cannot easily allow witnessing a broken invariant through the use of catch_unwind (catching a panic). This trait is an auto trait, so it is automatically implemented for many types, and it is also structurally composed (e.g., a struct is unwind safe if all of its components are unwind safe).

Note, however, that this is not an unsafe trait, so there is not a succinct contract that this trait is providing. Instead it is intended as more of a “speed bump” to alert users of catch_unwind that broken invariants may be witnessed and may need to be accounted for.

Who implements UnwindSafe?

Types such as &mut T and &RefCell<T> are examples which are not unwind safe. The general idea is that any mutable state which can be shared across catch_unwind is not unwind safe by default. This is because it is very easy to witness a broken invariant outside of catch_unwind as the data is simply accessed as usual.

Types like &Mutex<T>, however, are unwind safe because they implement poisoning by default. They still allow witnessing a broken invariant, but they already provide their own “speed bumps” to do so.

When should UnwindSafe be used?

It is not intended that most types or functions need to worry about this trait. It is only used as a bound on the catch_unwind function and as mentioned above, the lack of unsafe means it is mostly an advisory. The AssertUnwindSafe wrapper struct can be used to force this trait to be implemented for any closed over variables passed to catch_unwind.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Auto implementors



impl !UnwindSafe for core::io::error::Error



impl !UnwindSafe for Repr



impl UnwindSafe for !



impl UnwindSafe for ()



impl UnwindSafe for Abi



impl UnwindSafe for AddrKind



impl UnwindSafe for AddrParseError



impl UnwindSafe for AesOutput



impl UnwindSafe for core::mem::alignment::Alignment



impl UnwindSafe for core::fmt::Alignment



impl UnwindSafe for AlignmentEnum



impl UnwindSafe for AllocError



impl UnwindSafe for AlwaysEscaped



impl UnwindSafe for Array



impl UnwindSafe for AsciiChar



impl UnwindSafe for Assume



impl UnwindSafe for AtomicOrdering



impl UnwindSafe for BasicBlock



impl UnwindSafe for BiasedFp



impl UnwindSafe for Big8x3



impl UnwindSafe for Big32x40



impl UnwindSafe for Bool



impl UnwindSafe for BorrowError



impl UnwindSafe for BorrowMutError



impl UnwindSafe for ByteStr



impl UnwindSafe for BytesIsNotEmpty



impl UnwindSafe for CStr



impl UnwindSafe for CaseMappingIter



impl UnwindSafe for Char



impl UnwindSafe for CharCase



impl UnwindSafe for CharErrorKind



impl UnwindSafe for CharEscapeDebugContinue



impl UnwindSafe for CharEscapeDefault



impl UnwindSafe for CharEscapeUnicode



impl UnwindSafe for CharTryFromError



impl UnwindSafe for CodePointInner



impl UnwindSafe for Const



impl UnwindSafe for CpuidResult



impl UnwindSafe for DebugAsHex



impl UnwindSafe for Decimal



impl UnwindSafe for DecimalSeq



impl UnwindSafe for DecodeUtf16Error



impl UnwindSafe for Decoded



impl UnwindSafe for Direction



impl UnwindSafe for DriftsortRun



impl UnwindSafe for Duration



impl UnwindSafe for DynTrait



impl UnwindSafe for DynTraitPredicate



impl UnwindSafe for core::io::util::Empty



impl UnwindSafe for EmptyNeedle



impl UnwindSafe for EncodeKey128Output



impl UnwindSafe for EncodeKey256Output



impl UnwindSafe for Enum



impl UnwindSafe for core::fmt::Error



impl UnwindSafe for ErrorKind



impl UnwindSafe for EscapeByte



impl UnwindSafe for core::char::EscapeDebug



impl UnwindSafe for EscapeDebugExtArgs



impl UnwindSafe for core::ascii::EscapeDefault



impl UnwindSafe for core::char::EscapeDefault



impl UnwindSafe for core::char::EscapeUnicode



impl UnwindSafe for Field



impl UnwindSafe for FieldId



impl UnwindSafe for Float



impl UnwindSafe for FloatErrorKind



impl UnwindSafe for FnPtr



impl UnwindSafe for FormattingOptions



impl UnwindSafe for FpCategory



impl UnwindSafe for FromBytesUntilNulError



impl UnwindSafe for FromBytesWithNulError



impl UnwindSafe for FullDecoded



impl UnwindSafe for Generic



impl UnwindSafe for GenericType



impl UnwindSafe for GetDisjointMutError



impl UnwindSafe for I32NotAllOnes



impl UnwindSafe for I64NotAllOnes



impl UnwindSafe for IndexRange



impl UnwindSafe for Infallible



impl UnwindSafe for Int



impl UnwindSafe for IntErrorKind



impl UnwindSafe for Internal



impl UnwindSafe for IpAddr



impl UnwindSafe for Ipv4Addr



impl UnwindSafe for Ipv6Addr



impl UnwindSafe for Ipv6MulticastScope



impl UnwindSafe for IsAsciiWhitespace



impl UnwindSafe for IsNotEmpty



impl UnwindSafe for IsWhitespace



impl UnwindSafe for L1Lut



impl UnwindSafe for L2Lut



impl UnwindSafe for Last



impl UnwindSafe for Layout



impl UnwindSafe for LayoutError



impl UnwindSafe for Lifetime



impl UnwindSafe for LinesMap



impl UnwindSafe for LocalWaker



impl UnwindSafe for Locality



impl UnwindSafe for MatchOnly



impl UnwindSafe for MaybeEscaped



impl UnwindSafe for Nanoseconds



impl UnwindSafe for NeverShortCircuitResidual



impl UnwindSafe for NonZeroCharInner



impl UnwindSafe for NonZeroI8Inner



impl UnwindSafe for NonZeroI16Inner



impl UnwindSafe for NonZeroI32Inner



impl UnwindSafe for NonZeroI64Inner



impl UnwindSafe for NonZeroI128Inner



impl UnwindSafe for NonZeroIsizeInner



impl UnwindSafe for NonZeroU8Inner



impl UnwindSafe for NonZeroU16Inner



impl UnwindSafe for NonZeroU32Inner



impl UnwindSafe for NonZeroU64Inner



impl UnwindSafe for NonZeroU128Inner



impl UnwindSafe for NonZeroUsizeInner



impl UnwindSafe for OneSidedRangeBound



impl UnwindSafe for core::cmp::Ordering



impl UnwindSafe for core::sync::atomic::Ordering



impl UnwindSafe for PadAdapterState



impl UnwindSafe for ParseBoolError



impl UnwindSafe for ParseCharError



impl UnwindSafe for ParseFloatError



impl UnwindSafe for ParseIntError



impl UnwindSafe for PhantomPinned



impl UnwindSafe for Pointer



impl UnwindSafe for PostPadding



impl UnwindSafe for core::unicode::unicode_data::conversions::Range



impl UnwindSafe for RangeFull



impl UnwindSafe for RawWaker



impl UnwindSafe for RawWakerVTable



impl UnwindSafe for Reference



impl UnwindSafe for RejectAndMatch



impl UnwindSafe for core::io::util::Repeat



impl UnwindSafe for ReturnToArg



impl UnwindSafe for SearchStep



impl UnwindSafe for SeekFrom



impl UnwindSafe for ShortOffsetRunHeader



impl UnwindSafe for core::num::imp::flt2dec::Sign



impl UnwindSafe for core::fmt::Sign



impl UnwindSafe for SimdAlign



impl UnwindSafe for Sink



impl UnwindSafe for Sip13Rounds



impl UnwindSafe for Sip24Rounds



impl UnwindSafe for SipHasher



impl UnwindSafe for SipHasher24



impl UnwindSafe for Slice



impl UnwindSafe for SocketAddr



impl UnwindSafe for SocketAddrV4



impl UnwindSafe for SocketAddrV6



impl UnwindSafe for core::hash::sip::State



impl UnwindSafe for Str



impl UnwindSafe for StrSearcherImpl



impl UnwindSafe for Struct



impl UnwindSafe for ToCasefold



impl UnwindSafe for ToLowercase



impl UnwindSafe for ToTitlecase



impl UnwindSafe for ToUppercase



impl UnwindSafe for Trait



impl UnwindSafe for TryCaptureWithDebug



impl UnwindSafe for TryCaptureWithoutDebug



impl UnwindSafe for TryFromCharError



impl UnwindSafe for TryFromFloatSecsError



impl UnwindSafe for TryFromFloatSecsErrorKind



impl UnwindSafe for TryFromIntError



impl UnwindSafe for TryFromSliceError



impl UnwindSafe for Tuple



impl UnwindSafe for TwoWaySearcher



impl UnwindSafe for Type



impl UnwindSafe for TypeId



impl UnwindSafe for TypeKind



impl UnwindSafe for U32NotAllOnes



impl UnwindSafe for U64NotAllOnes



impl UnwindSafe for Union



impl UnwindSafe for UnsafeBytesToStr



impl UnwindSafe for UnwindActionArg



impl UnwindSafe for UnwindTerminateReason



impl UnwindSafe for UsizeNoHighBit



impl UnwindSafe for Utf8BoundaryError



impl UnwindSafe for Utf8Error



impl UnwindSafe for VaListInner



impl UnwindSafe for Variant



impl UnwindSafe for Waker



impl UnwindSafe for WideAesOutput



impl UnwindSafe for __m128



impl UnwindSafe for __m256



impl UnwindSafe for __m512



impl UnwindSafe for __m128bh



impl UnwindSafe for __m128d



impl UnwindSafe for __m128h



impl UnwindSafe for __m128i



impl UnwindSafe for __m256bh



impl UnwindSafe for __m256d



impl UnwindSafe for __m256h



impl UnwindSafe for __m256i



impl UnwindSafe for __m512bh



impl UnwindSafe for __m512d



impl UnwindSafe for __m512h



impl UnwindSafe for __m512i



impl UnwindSafe for __tile1024i



impl UnwindSafe for bf16



impl UnwindSafe for bool



impl UnwindSafe for c_void



impl UnwindSafe for char



impl UnwindSafe for f16



impl UnwindSafe for f32



impl UnwindSafe for f64



impl UnwindSafe for f128



impl UnwindSafe for i8



impl UnwindSafe for i16



impl UnwindSafe for i32



impl UnwindSafe for i64



impl UnwindSafe for i128



impl UnwindSafe for iovec



impl UnwindSafe for isize



impl UnwindSafe for str



impl UnwindSafe for u8



impl UnwindSafe for u16



impl UnwindSafe for u32



impl UnwindSafe for u64



impl UnwindSafe for u128



impl UnwindSafe for usize



impl<'a, 'b, const N: usize> UnwindSafe for CharArrayRefSearcher<'a, 'b, N>



impl<'a, 'b> !UnwindSafe for DebugInner<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugList<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugMap<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugSet<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugStruct<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugTuple<'a, 'b>



impl<'a, 'b> UnwindSafe for CharSliceSearcher<'a, 'b>



impl<'a, 'b> UnwindSafe for StrSearcher<'a, 'b>



impl<'a, A> !UnwindSafe for core::option::IterMut<'a, A>



impl<'a, A> UnwindSafe for core::option::Iter<'a, A>
where A: RefUnwindSafe,



impl<'a, C> UnwindSafe for MultiCharEqSearcher<'a, C>
where C: UnwindSafe,



impl<'a, F> UnwindSafe for CharPredicateSearcher<'a, F>
where F: UnwindSafe,



impl<'a, I, R> !UnwindSafe for GenericShunt<'a, I, R>



impl<'a, I> !UnwindSafe for ByRefSized<'a, I>



impl<'a, I> UnwindSafe for TaggedOption<'a, I>
where <I as Type<'a>>::Reified: UnwindSafe,



impl<'a, P> UnwindSafe for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for MatchIndicesInternal<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for MatchesInternal<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for core::str::iter::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for core::str::iter::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for core::str::iter::Split<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for core::str::iter::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for SplitInternal<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for core::str::iter::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for SplitNInternal<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, T, P> !UnwindSafe for ChunkByMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for RSplitMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for RSplitNMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for SplitInclusiveMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for SplitMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for SplitNMut<'a, T, P>



impl<'a, T, P> UnwindSafe for ChunkBy<'a, T, P>



impl<'a, T, P> UnwindSafe for core::slice::iter::RSplit<'a, T, P>



impl<'a, T, P> UnwindSafe for core::slice::iter::RSplitN<'a, T, P>



impl<'a, T, P> UnwindSafe for core::slice::iter::Split<'a, T, P>



impl<'a, T, P> UnwindSafe for core::slice::iter::SplitInclusive<'a, T, P>



impl<'a, T, P> UnwindSafe for core::slice::iter::SplitN<'a, T, P>



impl<'a, T, const N: usize> UnwindSafe for ArrayWindows<'a, T, N>
where T: RefUnwindSafe,



impl<'a, T> !UnwindSafe for BorrowedCursor<'a, T>



impl<'a, T> !UnwindSafe for ChunksExactMut<'a, T>



impl<'a, T> !UnwindSafe for ChunksMut<'a, T>



impl<'a, T> !UnwindSafe for core::mem::maybe_uninit::Guard<'a, T>



impl<'a, T> !UnwindSafe for core::array::Guard<'a, T>



impl<'a, T> !UnwindSafe for GuardBack<'a, T>



impl<'a, T> !UnwindSafe for InitializingSlice<'a, T>



impl<'a, T> !UnwindSafe for core::result::IterMut<'a, T>



impl<'a, T> !UnwindSafe for core::slice::iter::IterMut<'a, T>



impl<'a, T> !UnwindSafe for RChunksExactMut<'a, T>



impl<'a, T> !UnwindSafe for RChunksMut<'a, T>



impl<'a, T> UnwindSafe for Chunks<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for ChunksExact<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for core::result::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for core::slice::iter::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for RChunks<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for RChunksExact<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for Windows<'a, T>
where T: RefUnwindSafe,



impl<'a, const N: usize> UnwindSafe for CharArraySearcher<'a, N>



impl<'a> !UnwindSafe for ContextBuilder<'a>



impl<'a> !UnwindSafe for ExtData<'a>



impl<'a> !UnwindSafe for Formatter<'a>



impl<'a> !UnwindSafe for core::io::io_slice::repr::IoSliceMut<'a>



impl<'a> !UnwindSafe for core::io::io_slice::IoSliceMut<'a>



impl<'a> !UnwindSafe for Request<'a>



impl<'a> !UnwindSafe for Source<'a>



impl<'a> UnwindSafe for Argument<'a>



impl<'a> UnwindSafe for ArgumentType<'a>



impl<'a> UnwindSafe for Arguments<'a>



impl<'a> UnwindSafe for core::ffi::c_str::Bytes<'a>



impl<'a> UnwindSafe for core::str::iter::Bytes<'a>



impl<'a> UnwindSafe for CharIndices<'a>



impl<'a> UnwindSafe for CharSearcher<'a>



impl<'a> UnwindSafe for Chars<'a>



impl<'a> UnwindSafe for Context<'a>



impl<'a> UnwindSafe for Debug<'a>



impl<'a> UnwindSafe for EncodeUtf16<'a>



impl<'a> UnwindSafe for EscapeAscii<'a>



impl<'a> UnwindSafe for core::str::iter::EscapeDebug<'a>



impl<'a> UnwindSafe for core::str::iter::EscapeDefault<'a>



impl<'a> UnwindSafe for core::str::iter::EscapeUnicode<'a>



impl<'a> UnwindSafe for Formatted<'a>



impl<'a> UnwindSafe for core::io::io_slice::repr::IoSlice<'a>



impl<'a> UnwindSafe for core::io::io_slice::IoSlice<'a>



impl<'a> UnwindSafe for Lines<'a>



impl<'a> UnwindSafe for LinesAny<'a>



impl<'a> UnwindSafe for Location<'a>



impl<'a> UnwindSafe for PanicInfo<'a>



impl<'a> UnwindSafe for PanicMessage<'a>



impl<'a> UnwindSafe for Parser<'a>



impl<'a> UnwindSafe for Part<'a>



impl<'a> UnwindSafe for PhantomContravariantLifetime<'a>



impl<'a> UnwindSafe for PhantomCovariantLifetime<'a>



impl<'a> UnwindSafe for PhantomInvariantLifetime<'a>



impl<'a> UnwindSafe for SplitAsciiWhitespace<'a>



impl<'a> UnwindSafe for SplitWhitespace<'a>



impl<'a> UnwindSafe for Utf8Chunk<'a>



impl<'a> UnwindSafe for Utf8Chunks<'a>



impl<'a> UnwindSafe for Utf8Pattern<'a>



impl<'a> UnwindSafe for VaList<'a>



impl<'b, T> !UnwindSafe for core::cell::Ref<'b, T>



impl<'b, T> !UnwindSafe for RefMut<'b, T>



impl<'b> !UnwindSafe for BorrowRef<'b>



impl<'b> !UnwindSafe for BorrowRefMut<'b>



impl<'buf, 'state> !UnwindSafe for PadAdapter<'buf, 'state>



impl<'data, T> !UnwindSafe for BorrowedBuf<'data, T>



impl<'l, 'f, T, F> !UnwindSafe for Drain<'l, 'f, T, F>



impl<A, B> UnwindSafe for core::iter::adapters::chain::Chain<A, B>
where A: UnwindSafe, B: UnwindSafe,



impl<A, B> UnwindSafe for Zip<A, B>
where A: UnwindSafe, B: UnwindSafe,



impl<A> UnwindSafe for core::option::IntoIter<A>
where A: UnwindSafe,



impl<A> UnwindSafe for Item<A>
where A: UnwindSafe,



impl<A> UnwindSafe for OptionFlatten<A>
where A: UnwindSafe,



impl<A> UnwindSafe for RangeFromIter<A>
where A: UnwindSafe,



impl<A> UnwindSafe for RangeInclusiveIter<A>
where A: UnwindSafe,



impl<A> UnwindSafe for RangeIter<A>
where A: UnwindSafe,



impl<A> UnwindSafe for core::iter::sources::repeat::Repeat<A>
where A: UnwindSafe,



impl<A> UnwindSafe for RepeatN<A>
where A: UnwindSafe,



impl<B, C> UnwindSafe for ControlFlow<B, C>
where C: UnwindSafe, B: UnwindSafe,



impl<C> UnwindSafe for ErrorData<C>
where C: UnwindSafe,



impl<C> UnwindSafe for MultiCharEqPattern<C>
where C: UnwindSafe,



impl<DATA> UnwindSafe for PolymorphicIter<DATA>
where DATA: UnwindSafe + ?Sized,



impl<Dyn> !UnwindSafe for DynMetadata<Dyn>



impl<E, M> UnwindSafe for Capture<E, M>
where E: UnwindSafe, M: UnwindSafe,



impl<E> UnwindSafe for Tagged<E>
where E: UnwindSafe + ?Sized,



impl<F> UnwindSafe for core::iter::sources::from_fn::FromFn<F>
where F: UnwindSafe,



impl<F> UnwindSafe for core::fmt::builders::FromFn<F>
where F: UnwindSafe,



impl<F> UnwindSafe for MaybeDone<F>
where F: UnwindSafe, <F as Future>::Output: UnwindSafe,



impl<F> UnwindSafe for OnceWith<F>
where F: UnwindSafe,



impl<F> UnwindSafe for PollFn<F>
where F: UnwindSafe,



impl<F> UnwindSafe for RepeatWith<F>
where F: UnwindSafe,



impl<G> UnwindSafe for FromCoroutine<G>
where G: UnwindSafe,



impl<H> UnwindSafe for BuildHasherDefault<H>



impl<I, F, const N: usize> UnwindSafe for MapWindows<I, F, N>
where F: UnwindSafe, I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<I, F> UnwindSafe for FilterMap<I, F>
where I: UnwindSafe, F: UnwindSafe,



impl<I, F> UnwindSafe for Inspect<I, F>
where I: UnwindSafe, F: UnwindSafe,



impl<I, F> UnwindSafe for Map<I, F>
where I: UnwindSafe, F: UnwindSafe,



impl<I, G> UnwindSafe for IntersperseWith<I, G>
where G: UnwindSafe, I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<I, P> UnwindSafe for Filter<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, P> UnwindSafe for MapWhile<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, P> UnwindSafe for SkipWhile<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, P> UnwindSafe for TakeWhile<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, St, F> UnwindSafe for Scan<I, St, F>
where I: UnwindSafe, F: UnwindSafe, St: UnwindSafe,



impl<I, U, F> UnwindSafe for FlatMap<I, U, F>



impl<I, U> UnwindSafe for FlattenCompat<I, U>
where U: UnwindSafe, I: UnwindSafe,



impl<I, const N: usize> UnwindSafe for ArrayChunks<I, N>
where I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<I, const N: usize> UnwindSafe for MapWindowsInner<I, N>
where I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<I> UnwindSafe for Cloned<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Copied<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Cycle<I>
where I: UnwindSafe,



impl<I> UnwindSafe for DecodeUtf16<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Enumerate<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Flatten<I>



impl<I> UnwindSafe for FromIter<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Fuse<I>
where I: UnwindSafe,



impl<I> UnwindSafe for GenericSplitN<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Intersperse<I>
where <I as Iterator>::Item: Sized + UnwindSafe, I: UnwindSafe,



impl<I> UnwindSafe for Peekable<I>
where I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<I> UnwindSafe for core::error::tags::Ref<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Skip<I>
where I: UnwindSafe,



impl<I> UnwindSafe for StepBy<I>
where I: UnwindSafe,



impl<I> UnwindSafe for core::iter::adapters::take::Take<I>
where I: UnwindSafe,



impl<Idx> UnwindSafe for Clamp<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::ops::range::Range<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::range::Range<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::ops::range::RangeFrom<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::range::RangeFrom<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::ops::range::RangeInclusive<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::range::RangeInclusive<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for RangeTo<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::ops::range::RangeToInclusive<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::range::RangeToInclusive<Idx>
where Idx: UnwindSafe,



impl<P> UnwindSafe for MaybeDangling<P>
where P: UnwindSafe + ?Sized,



impl<Ptr> UnwindSafe for Pin<Ptr>
where Ptr: UnwindSafe,



impl<Ptr> UnwindSafe for PinHelper<Ptr>
where Ptr: UnwindSafe,



impl<Ret, T> UnwindSafe for fn(T₁, T₂, …, Tₙ) -> Ret



impl<S> UnwindSafe for Hasher<S>
where S: UnwindSafe,



impl<T, E> UnwindSafe for Result<T, E>
where T: UnwindSafe, E: UnwindSafe,



impl<T, F> UnwindSafe for DropGuard<T, F>
where T: UnwindSafe, F: UnwindSafe,



impl<T, F> UnwindSafe for LazyCell<T, F>
where F: UnwindSafe, T: UnwindSafe,



impl<T, F> UnwindSafe for core::cell::lazy::State<T, F>
where F: UnwindSafe, T: UnwindSafe,



impl<T, F> UnwindSafe for Successors<T, F>
where F: UnwindSafe, T: UnwindSafe,



impl<T, U> UnwindSafe for core::io::util::Chain<T, U>
where T: UnwindSafe, U: UnwindSafe,



impl<T, const N: usize> UnwindSafe for AlignedStorage<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for Buffer<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for core::array::iter::IntoIter<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for Mask<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for core::core_arch::simd::Simd<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for core::core_simd::vector::Simd<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for SimdM<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for [MaybeUninit<T>; N]
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for [Option<T>; N]
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for [T; N]
where T: UnwindSafe,



impl<T, const VARIANT: u32, const FIELD: u32> UnwindSafe for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,



impl<T> !UnwindSafe for TraitImpl<T>



impl<T> UnwindSafe for (T₁, T₂, …, Tₙ)
where T: UnwindSafe,



impl<T> UnwindSafe for Align1<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Align2<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Align4<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Align8<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Atomic<T>



impl<T> UnwindSafe for Bound<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Cell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for CopyOnDrop<T>
where T: RefUnwindSafe,



impl<T> UnwindSafe for Cursor<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Discriminant<T>



impl<T> UnwindSafe for core::iter::sources::empty::Empty<T>



impl<T> UnwindSafe for GapGuard<T>



impl<T> UnwindSafe for GapGuardRaw<T>
where T: RefUnwindSafe,



impl<T> UnwindSafe for core::result::IntoIter<T>
where T: UnwindSafe,



impl<T> UnwindSafe for ManuallyDrop<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for MaybeSizedValue<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for MaybeUninit<T>
where T: UnwindSafe,



impl<T> UnwindSafe for MergeState<T>
where T: RefUnwindSafe,



impl<T> UnwindSafe for NeverShortCircuit<T>
where T: UnwindSafe,



impl<T> UnwindSafe for NumBuffer<T>



impl<T> UnwindSafe for Once<T>
where T: UnwindSafe,



impl<T> UnwindSafe for OnceCell<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Option<T>
where T: UnwindSafe,



impl<T> UnwindSafe for core::slice::sort::stable::quicksort::PartitionState<T>
where T: RefUnwindSafe,



impl<T> UnwindSafe for core::slice::sort::unstable::quicksort::PartitionState<T>
where T: RefUnwindSafe,



impl<T> UnwindSafe for Pending<T>



impl<T> UnwindSafe for PhantomContravariant<T>
where T: ?Sized,



impl<T> UnwindSafe for PhantomCovariant<T>
where T: ?Sized,



impl<T> UnwindSafe for PhantomData<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for PhantomInvariant<T>
where T: ?Sized,



impl<T> UnwindSafe for Poll<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Ready<T>
where T: UnwindSafe,



impl<T> UnwindSafe for RefCell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for RepeatNInner<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Rev<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Reverse<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Saturating<T>
where T: UnwindSafe,



impl<T> UnwindSafe for SyncUnsafeCell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for SyncView<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for core::io::util::Take<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Unaligned<T>
where T: UnwindSafe,



impl<T> UnwindSafe for UnsafeCell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for UnsafePinned<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for Value<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Wrapper<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Wrapping<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Yeet<T>
where T: UnwindSafe,



impl<T> UnwindSafe for [T]
where T: UnwindSafe,



impl<Y, R> UnwindSafe for CoroutineState<Y, R>
where Y: UnwindSafe, R: UnwindSafe,



impl<const LEN: usize> UnwindSafe for SimdShuffleIdx<LEN>



impl<const N: usize, ESCAPING> UnwindSafe for EscapeIterInner<N, ESCAPING>
where ESCAPING: UnwindSafe,



impl<const N: usize> UnwindSafe for MaybeEscapedCharacter<N>



impl<const N: usize> UnwindSafe for [u8; N]



impl<const SIZE: usize> UnwindSafe for DisplayBuffer<SIZE>